module.exports = defineTest({
	description: 'properly handle the results of mutating logical expressions',
	options: { output: { name: 'bundle' } }
});
